@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Sah::Schemas;
 
 our $DATE = '2018-01-14'; # DATE
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict;
@@ -234,11 +234,14 @@ sub register_prereqs {
 
     for my $mod (sort keys %{$self->{_our_schema_modules} // {}}) {
         my $nsch = ${"$mod\::schema"};
-        if ($nsch->[1]{'x.completion'}) {
-            my $xcmod = "Perinci::Sub::XCompletion::".
-                $nsch->[1]{'x.completion'};
-            $self->log(["Adding prereq to %s", $xcmod]);
-            $self->zilla->register_prereqs({phase=>'runtime'}, $xcmod => 0);
+        if (my $xc = $nsch->[1]{'x.completion'}) {
+            my @c = ref($xc) eq 'CODE' ? () :
+                ref($xc) eq 'ARRAY' ? @$xc : ($xc);
+            for my $c (@c) {
+                my $xcmod = "Perinci::Sub::XCompletion::$c";
+                $self->log(["Adding prereq to %s", $xcmod]);
+                $self->zilla->register_prereqs({phase=>'runtime'}, $xcmod => 0);
+            }
         }
     }
 }
@@ -259,7 +262,7 @@ Dist::Zilla::Plugin::Sah::Schemas - Plugin to use when building Sah-Schemas-* di
 
 =head1 VERSION
 
-This document describes version 0.009 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2018-01-14.
+This document describes version 0.010 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2018-01-14.
 
 =head1 SYNOPSIS
 
